from ehelply_bootstrapper.utils.state import State
from ehelply_bootstrapper.drivers.driver import Driver
from ehelply_bootstrapper.utils.connection_details import ConnectionDetails
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
from sqlalchemy.orm import sessionmaker

from fastapi import FastAPI
from starlette.requests import Request
from starlette.responses import Response

from pydantic import BaseModel


class MySQLCredentials(ConnectionDetails):
    database: str


class Mysql(Driver):
    def __init__(self, credentials: MySQLCredentials, verbosity: int = 0):
        super().__init__(verbosity=verbosity)
        self.Base = None
        self.SessionLocal = None
        self.credentials: MySQLCredentials = credentials

        self.use_async: bool = False

        try:
            if State.config.sql.use_async:
                self.use_async = State.config.sql.use_async
        except:
            State.logger.warning("MySQL config file is missing use_async boolean. Defaulting to false.")

    def setup(self):

        if self.use_async:
            engine = create_async_engine(
                self.make_connection_string(
                    "mysql",
                    self.credentials.host,
                    self.credentials.port,
                    self.credentials.database,
                    self.credentials.username,
                    self.credentials.password
                ),
                pool_pre_ping=True,
                pool_size=4,
                max_overflow=4
            )

            self.SessionLocal = sessionmaker(
                autocommit=False,
                autoflush=False,
                bind=engine,
                expire_on_commit=False,
                class_=AsyncSession
            )
        else:
            engine = create_engine(
                self.make_connection_string(
                    "mysql",
                    self.credentials.host,
                    self.credentials.port,
                    self.credentials.database,
                    self.credentials.username,
                    self.credentials.password
                ),
                pool_pre_ping=True,
                pool_size=4,
                max_overflow=4
            )

            self.SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

        self.Base = declarative_base()

    def make_connection_string(self, driver: str, host: str, port: int, database_name: str, username: str,
                               password: str):
        driver_type: str = "pymysql"
        if self.use_async:
            driver_type = "aiomysql"

        return driver + '+aiomysql://' + username + ':' + password + '@' + host + ':' + str(port) + '/' + database_name

    # def inject_fastapi_middleware(self, app: FastAPI):
    #     @app.middleware("http")
    #     async def db_session_middleware(request: Request, call_next):
    #         response = Response("Internal server error", status_code=500)
    #         try:
    #             request.state.db = self.SessionLocal()
    #             response = await call_next(request)
    #         finally:
    #             request.state.db.close()
    #         return response
